@@ -13,11 +13,11 @@
 ##############################################################################
 """Test Unauthorized Exception Views
 
-$Id: test_unauthorized.py 100113 2009-05-18 20:08:41Z icemac $
+$Id: test_unauthorized.py 107631 2010-01-04 15:17:15Z janwijbrand $
 """
 from unittest import TestCase, main, makeSuite
 from zope import component, interface
-import zope.app.pagetemplate.namedtemplate
+import zope.browserpage.namedtemplate
 from zope.publisher.browser import TestRequest
 from zope.authentication.interfaces import IAuthentication
 from zope.security.interfaces import IPrincipal
@@ -51,7 +51,7 @@ class DummyTemplate(object):
         self.context = context
 
     component.adapts(Unauthorized)
-    interface.implements(zope.app.pagetemplate.namedtemplate.INamedTemplate)
+    interface.implements(zope.browserpage.namedtemplate.INamedTemplate)
 
     def __call__(self):
         return 'You are not authorized'
