@@ -1,7 +1,7 @@
 ##############################################################################
 # Copyright (c) 2003 Zope Corporation and Contributors.
 # All Rights Reserved.
-# 
+#
 # This software is subject to the provisions of the Zope Public License,
 # Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
 # THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
@@ -11,17 +11,9 @@
 ##############################################################################
 """General exceptions
 
-$Id: interfaces.py 97488 2009-03-04 20:14:51Z nadako $
+$Id: interfaces.py 100078 2009-05-18 17:08:59Z icemac $
 """
 __docformat__ = 'restructuredtext'
 
-from zope.interface import Interface
-
-
-class ISystemErrorView(Interface):
-    """Error views that can classify their contexts as system errors
-    """
-
-    def isSystemError():
-        """Return a boolean indicating whether the error is a system errror
-        """
+# BBB
+from zope.browser.interfaces import ISystemErrorView
